@@ -4,7 +4,7 @@
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
  * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
+ * version 2 of the License, or (at your option) any later version.
  * 
  * This software is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,7 +13,7 @@
  * 
  * You should have received a copy of the GNU General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #include <crm_internal.h>
@@ -118,14 +118,14 @@ crm_timer_popped(gpointer data)
 	   || timer == recheck_timer
 	   || timer == finalization_timer
 	   || timer == election_trigger) {
-		crm_info("%s (%s) just popped!",
-			get_timer_desc(timer),
-			fsa_input2string(timer->fsa_input));
+	    crm_info("%s (%s) just popped! (%dms)",
+		     get_timer_desc(timer),
+		     fsa_input2string(timer->fsa_input), timer->period_ms);
 		
 	} else {
-		crm_err("%s (%s) just popped!",
-			get_timer_desc(timer),
-			fsa_input2string(timer->fsa_input));
+	    crm_err("%s (%s) just popped! (%dms)",
+		    get_timer_desc(timer),
+		    fsa_input2string(timer->fsa_input), timer->period_ms);
 	}
 
 	if(timer->repeat == FALSE) {
@@ -654,6 +654,10 @@ fsa_action2string(long long action)
 		case A_WARN:
 			actionAsText = "A_WARN  ";
 			break;
+			/* Composite actions */
+		case A_DC_TIMER_START|A_CL_JOIN_QUERY:
+			actionAsText = "A_DC_TIMER_START|A_CL_JOIN_QUERY";
+			break;
 	}
 
 	if(actionAsText == NULL) {
@@ -1168,7 +1172,7 @@ gboolean update_dc(xmlNode *msg)
 		    crm_warn("New DC %s is not %s", welcome_from, fsa_our_dc);
 		}
 
-		register_fsa_action(A_CL_JOIN_QUERY);
+		register_fsa_action(A_CL_JOIN_QUERY|A_DC_TIMER_START);
 		return FALSE;
 	    }
 	}
@@ -1260,7 +1264,7 @@ attrd_connection_destroy(gpointer user_data)
 }
 
 void
-update_attrd(const char *host, const char *name, const char *value) 
+update_attrd(const char *host, const char *name, const char *value, const char *user_name)
 {	
     int retries = 5;
     gboolean rc = FALSE;
@@ -1276,7 +1280,7 @@ update_attrd(const char *host, const char *name, const char *value)
     }
     
     if(attrd != NULL) {
-	rc = attrd_update(attrd, 'U', host, name, value, XML_CIB_TAG_STATUS, NULL, NULL);
+	rc = attrd_update_delegate(attrd, 'U', host, name, value, XML_CIB_TAG_STATUS, NULL, NULL, user_name);
 	
     } else {
 	crm_warn("Could not connect to %s", T_ATTRD);
